@@ -6,9 +6,9 @@ from functools import lru_cache
 from pathlib import Path
 from subprocess import CalledProcessError  # nosec
 
-import attr
 import pandas as pd
 import pendulum
+from attrs import field, frozen
 from attrs_strict import type_validator
 from beartype import beartype
 from beartype.typing import Dict, List, Optional, Pattern, Sequence, Tuple
@@ -24,7 +24,7 @@ SKIP_PHRASE = 'calcipy:skip_tags'
 COMMON_CODE_TAGS = ['FIXME', 'TODO', 'PLANNED', 'HACK', 'REVIEW', 'TBD', 'DEBUG']  # noqa: T100,T101,T103
 """Most common code tags. FYI and NOTE are excluded to not be tracked in the Code Summary."""
 
-CODE_TAG_RE = r'((\s|\()(?P<tag>{tag})(:| -)([^\r\n]))(?P<text>.+)'
+CODE_TAG_RE = r'((^|\s|\(|"|\')(?P<tag>{tag})(:| -)([^\r\n]))(?P<text>.+)'
 """Default code tag regex with `tag` and `text` matching groups.
 
 Requires formatting with list of tags: `CODE_TAG_RE.format(tag='|'.join(tag_list))`
@@ -34,21 +34,21 @@ Commonly, the `tag_list` could be `COMMON_CODE_TAGS`
 """
 
 
-@attr.s(auto_attribs=True)
+@frozen
 class _CodeTag:  # noqa: H601
     """Code Tag (FIXME,TODO,etc) with contextual information."""  # noqa: T100,T101
 
-    lineno: int = attr.ib(validator=type_validator())
-    tag: str = attr.ib(validator=type_validator())
-    text: str = attr.ib(validator=type_validator())
+    lineno: int = field(validator=type_validator())
+    tag: str = field(validator=type_validator())
+    text: str = field(validator=type_validator())
 
 
-@attr.s(auto_attribs=True)
+@frozen
 class _Tags:  # noqa: H601
     """Collection of code tags with additional contextual information."""
 
-    path_source: Path = attr.ib(validator=type_validator())
-    code_tags: List[_CodeTag] = attr.ib(validator=type_validator())
+    path_source: Path = field(validator=type_validator())
+    code_tags: List[_CodeTag] = field(validator=type_validator())
 
 
 @beartype
@@ -99,13 +99,14 @@ def _search_files(paths_source: Sequence[Path], regex_compiled: Pattern[str]) ->
         except UnicodeDecodeError as err:
             logger.debug('Could not parse: {path_source}', path_source=path_source, err=err)
 
-        if comments := _search_lines(lines, regex_compiled):
+        comments = _search_lines(lines, regex_compiled)
+        if comments:
             matches.append(_Tags(path_source, comments))
 
     return matches
 
 
-@lru_cache
+@lru_cache(maxsize=128)
 @beartype
 def _git_info(cwd: Path) -> Tuple[Path, str]:
     """Collect information about the local git repository.
@@ -247,5 +248,5 @@ def write_code_tag_file(
 
     if report:
         path_tag_summary.write_text(f'{header}\n\n{report}\n\n<!-- {SKIP_PHRASE} -->\n')
-    else:
-        path_tag_summary.unlink(missing_ok=True)
+    elif path_tag_summary.is_file():
+        path_tag_summary.unlink()
